@@ -48,7 +48,7 @@ class modelGenerator(ExcelImporter):
         dfTableList = self.get_TableListByDataFrame(tableListSheetName)
 
         for sheetname in self.sheets:
-            if str(sheetname).startswith(('trn','mst','log')): 
+            if str(sheetname).startswith(('trn','mst','log','prm')): 
                 # テーブル定義をDataFrameで取得
                 dfDef = self.get_TableDefByDataFrame(sheetname)
                 # Model内容をpythonファイル出力
@@ -69,7 +69,7 @@ class modelGenerator(ExcelImporter):
         dfTableList = self.get_TableListByDataFrame(tableListSheetName)
         
         for sheetname in self.sheets:
-            if str(sheetname).startswith(('trn','mst','log')): 
+            if str(sheetname).startswith(('trn','mst','log','prm')): 
                 # テーブル定義をDataFrameで取得
                 dfDef = self.get_TableDefByDataFrame(sheetname)
                 # Model内容をsqlファイル出力
